@@ -7,5 +7,10 @@
 ##########################################################################
 
 
-from util import *
-from model import Model
+from .util import *
+from .model import Model
+
+try:
+    from sqlalchemy.orm import sessionmaker
+except ImportError:
+    raise ImportError('z3c.sqlalchemy requires SQLAlchemy 0.4 or higher')
