@@ -6,9 +6,9 @@
 # and ZOPYX Ltd. & Co. KG, Tuebingen, Germany
 ##########################################################################
 
-from zope.interface import implements
+from zope.interface import implementer
 from zope.component import getUtility
-from zope.component.interfaces import ComponentLookupError
+from zope.interface.interfaces import ComponentLookupError
 
 from z3c.sqlalchemy.model import Model
 from z3c.sqlalchemy.mapper import LazyMapperCollection
@@ -17,16 +17,16 @@ from z3c.sqlalchemy.interfaces import ISQLAlchemyWrapper, IModelProvider
 
 from sqlalchemy import create_engine, MetaData
 from sqlalchemy.engine.url import make_url
-from sqlalchemy.orm import scoped_session, sessionmaker, relation
-from zope.sqlalchemy import ZopeTransactionExtension
+from sqlalchemy.orm import scoped_session, sessionmaker
+from zope.sqlalchemy import register
 
+from six import string_types
 
+@implementer(ISQLAlchemyWrapper)
 class ZopeWrapper(object):
 
-    implements(ISQLAlchemyWrapper)
-
     def __init__(self, dsn, model=None, transactional=True, twophase=False,
-                 engine_options={}, session_options={}, 
+                 engine_options={}, session_options={},
                  extension_options={}, **kw):
         """ 'dsn' - a RFC-1738-style connection string
 
@@ -38,10 +38,10 @@ class ZopeWrapper(object):
             'session_options' - optional keyword arguments passed to
             create_session() or sessionmaker()
 
-            'extension_options' - optional keyword argument passed to 
+            'extension_options' - optional keyword argument passed to
             ZopeTransactionExtension()
 
-            'transactional' - True|False, only used by SQLAlchemyDA, 
+            'transactional' - True|False, only used by SQLAlchemyDA,
                               *don't touch it*
         """
 
@@ -51,7 +51,7 @@ class ZopeWrapper(object):
         self.port = self.url.port
         self.username = self.url.username
         self.password = self.url.password
-        self.dbname = self.url.database 
+        self.dbname = self.url.database
         self.twophase = twophase
         self.drivername = self.url.drivername
         self.transactional = transactional
@@ -68,7 +68,7 @@ class ZopeWrapper(object):
             if isinstance(model, Model):
                 self._model = model
 
-            elif isinstance(model, basestring):
+            elif isinstance(model, string_types):
 
                 try:
                     util = getUtility(IModelProvider, model)
@@ -81,14 +81,13 @@ class ZopeWrapper(object):
                 self._model = model(self.metadata)
 
             else:
-                raise ValueError("The 'model' parameter passed to constructor must either be "\
-                                 "the name of a named utility implementing IModelProvider or "\
+                raise ValueError("The 'model' parameter passed to constructor must either be "
+                                 "the name of a named utility implementing IModelProvider or "
                                  "an instance of z3c.sqlalchemy.model.Model.")
 
             if not isinstance(self._model, Model):
                 raise TypeError('_model is not an instance of model.Model')
 
-
         # mappers must be initialized at last since we need to acces
         # the 'model' from within the constructor of LazyMapperCollection
         self._mappers = LazyMapperCollection(self)
@@ -134,10 +133,9 @@ class ZopeWrapper(object):
 
     def _createEngine(self):
         self._engine = create_engine(self.dsn, **self.engine_options)
-        self._sessionmaker = scoped_session(sessionmaker(bind=self._engine, 
+        self._sessionmaker = scoped_session(sessionmaker(bind=self._engine,
                                             autocommit=not self.transactional,
                                             twophase=self.twophase,
-                                            autoflush=True, 
-                                            extension=ZopeTransactionExtension(**self.extension_options),
-                                            **self.session_options
-                                            ))
+                                            autoflush=True,
+                                            **self.session_options))
+        register(self._sessionmaker)
